@@ -9,8 +9,12 @@ from rich.table import Table
 
 from neuralspace import VERSION
 from neuralspace.apis import get_async_http_session
+from neuralspace.augmentation.commands import augmentation
+from neuralspace.language_detection.commands import language_detection
 from neuralspace.ner.commands import ner
 from neuralspace.nlu.commands import nlu
+from neuralspace.translation.commands import translation
+from neuralspace.transliteration.commands import transliteration
 from neuralspace.utils import (
     add_apps_to_table,
     add_heading_to_description_table,
@@ -98,6 +102,10 @@ def login(email: Text, password: Text, log_level: Text):
 
 entrypoint.add_command(nlu)
 entrypoint.add_command(ner)
+entrypoint.add_command(translation)
+entrypoint.add_command(transliteration)
+entrypoint.add_command(augmentation)
+entrypoint.add_command(language_detection)
 
 if __name__ == "__main__":
     entrypoint()
