@@ -114,6 +114,19 @@ PRE_TRAINED = "pre-trained"
 LOOKUP = "lookup"
 SYNONYM = "synonym"
 REGEX = "regex"
+NAME = "name"
+PATTERN = "pattern"
+ELEMENTS = "elements"
+ENTITY_SYNONYMS = "entity_synonyms"
+LOOKUP_TABLES = "lookup_tables"
+REGEX_FEATURES = "regex_features"
+COMMON_EXAMPLES = "common_examples"
+SYNONYMS = "synonyms"
+TRANSLATED_TEXT = "translated_text"
+TRANSLITERATED_TEXT = "transliterated_text"
+SUGGESTIONS = "suggestions"
+DETECTED_LANGUAGES = "detected_languages"
+AUGMENTATION_SUGGESTIONS = "augmentation_suggestions"
 
 # supported entity types
 NER_TYPES = [PRE_TRAINED, LOOKUP, SYNONYM, REGEX]
@@ -125,6 +138,8 @@ INSTALL_APP_COMMAND = "neuralspace install-app --help"
 TRAIN_MODEL_COMMAND = "neuralspace nlu train --help"
 DEPLOY_MODEL_COMMAND = "neuralspace nlu deploy --help"
 PARSE_MODEL_COMMAND = "neuralspace nlu parse --help"
+
+
 # checking command
 
 APP_IS_INSTALLED = "App is already installed"
@@ -171,5 +186,7 @@ DARK_ORANGE_END = "[/dark_orange3]"
 INFO = "[deep_sky_blue2]INFO[/deep_sky_blue2]"
 BOLD_START = "[bold]"
 BOLD_END = "[/bold]"
+GREEN_START = "[green]"
+GREEN_END = "[/green]"
 LOGO_HASH = ""
 ERROR = f"{RED_START}ERROR{RED_END}"
