@@ -5,8 +5,17 @@ from datetime import datetime
 from typing import Any, Dict, List, Text, Tuple
 
 from rich.console import Console
-from rich.progress import track
+from rich.progress import (
+    BarColumn,
+    Progress,
+    SpinnerColumn,
+    Task,
+    TextColumn,
+    TimeRemainingColumn,
+    TransferSpeedColumn,
+)
 from rich.table import Table
+from rich.text import Text as Text_render
 
 from neuralspace.apis import get_async_http_session
 from neuralspace.constants import (
@@ -30,7 +39,6 @@ from neuralspace.constants import (
     END_INDEX,
     ENTITIES,
     ENTITY_ACC,
-    ENTITY_TYPE,
     ERROR,
     EXAMPLE,
     EXAMPLE_ID,
@@ -50,7 +58,6 @@ from neuralspace.constants import (
     LANGUAGE,
     LANGUAGES,
     LAST_STATUS_UPDATED,
-    LIST_ENTITY_URL,
     MESSAGE,
     METRICS,
     MODEL_ID,
@@ -126,6 +133,15 @@ from neuralspace.utils import get_auth_token, is_success_status, print_ner_respo
 console = Console()
 
 
+class CustomisedTransferSpeedColumn(TransferSpeedColumn):
+    def render(self, task: Task) -> Text_render:
+        """Show data transfer speed."""
+        speed = task.finished_speed or task.speed
+        if speed is None:
+            return Text_render("?", style="progress.data.speed")
+        return Text_render(f"{speed: .2f} examples/s", style="progress.data.speed")
+
+
 async def get_languages() -> Dict[Text, Any]:
     console.print(f"> {INFO} {DOWN_ARROW}️ Fetching all supported languages for NLU")
     HEADERS = copy(COMMON_HEADERS)
@@ -453,7 +469,7 @@ async def list_models(
         if is_success_status(response.status):
             print_models_table(json_response, verbose)
             console.print(
-                f"[orange4]{FAST_FORWARD} To deploy the model: [/orange4]{DEPLOY_MODEL_COMMAND}{DARK_ORANGE_END}"
+                f"{FAST_FORWARD} To deploy the model: {DARK_ORANGE_START}{DEPLOY_MODEL_COMMAND}{DARK_ORANGE_START}"
             )
         else:
             console.print(f"> {ERROR} {CROSS} Failed to list models")
@@ -498,13 +514,26 @@ async def upload_dataset(
         f"examples for project {project_id} and language {language}"
     )
     console.print(f"> {INFO} Skipping first {skip_first} examples")
-    for chunk_id, example in track(
-        enumerate(nlu_data[skip_first:]),
-        description="[bold orange4]uploading[/bold orange4]...",
-        total=len(
-            nlu_data[skip_first:],
+    Total_number_examples = len(nlu_data[skip_first:])
+    current_example_number = 0
+    progress_bar = Progress(
+        SpinnerColumn(),
+        TextColumn(
+            "[orange3]Uploading...[/orange3]"
+            " [dark_green]{task.completed}[/dark_green]/[dark_green]{task.total}[/dark_green]"
         ),
-    ):
+        BarColumn(bar_width=50),
+        "[progress.percentage]{task.percentage:>3.0f}%",
+        TimeRemainingColumn(),
+        CustomisedTransferSpeedColumn(),
+        "[orange3][progress.description]{task.description}[/orange3]",
+    )
+    task = progress_bar.add_task(description="", total=Total_number_examples)
+    progress_bar.update(task)
+    animation_tracker = 1
+    for chunk_id, example in enumerate(nlu_data):
+        progress_bar.start()
+        current_example_number += 1
         batch = {PROJECT_ID: project_id, LANGUAGE: language, EXAMPLE: example}
         HEADERS = copy(COMMON_HEADERS)
         HEADERS[AUTHORIZATION] = get_auth_token()
@@ -515,12 +544,24 @@ async def upload_dataset(
         ) as response:
             json_response = await response.json(encoding="utf-8")
             if is_success_status(response.status):
+                if current_example_number % 3 == 0:
+                    if animation_tracker == 1:
+                        progress_bar.update(task_id=task, description="🏃")
+                        animation_tracker = 2
+                    elif animation_tracker == 2:
+                        progress_bar.update(task_id=task, description="🚶")
+                        animation_tracker = 3
+                    elif animation_tracker == 3:
+                        progress_bar.update(task_id=task, description="🏃")
+                        animation_tracker = 1
                 responses.append(json_response)
+                progress_bar.update(task_id=task, completed=current_example_number)
             else:
                 console.print(
                     f"> {ERROR} {CROSS} Failed to upload example with text "
                     f"{DARK_ORANGE_START}{example['text']}{DARK_ORANGE_END}"
                 )
+
                 console.print(
                     f"> Failed on example: \n{json.dumps(example, indent=4, ensure_ascii=False)}"
                 )
@@ -532,14 +573,16 @@ async def upload_dataset(
                     continue
                 else:
                     break
-    console.print(f"> {INFO} {GREEN_TICK} Uploaded {len(responses)} examples")
+    console.print(f"\n> {INFO} {GREEN_TICK} Uploaded {len(responses)} examples")
     console.print(f"> {INFO} {CROSS} Failed on {len(error_examples)} examples")
-    console.print(f"To train your model: {TRAIN_MODEL_COMMAND}")
     with open("failed_examples.json", "w") as f:
         json.dump(error_examples, f, ensure_ascii=False)
         console.print(
             f"> {INFO} {WRITING} Writing failed examples into failed_examples.json"
         )
+    console.print(
+        f"To train your model: {DARK_ORANGE_START}{TRAIN_MODEL_COMMAND}{DARK_ORANGE_END}"
+    )
     return responses
 
 
@@ -579,6 +622,11 @@ async def wait_till_training_completes(
                                     f"{FAST_FORWARD} To deploy your model on Neuralspace platform: "
                                     f"{DARK_ORANGE_START}{DEPLOY_MODEL_COMMAND}{DARK_ORANGE_END}"
                                 )
+                            if json_response[DATA][TRAINING_STATUS] == FAILED:
+                                console.print(
+                                    f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response[DATA]['message']}{RED_END}\
+                                     "'''
+                                )
                             break
                     else:
                         console.print(f"> {ERROR} Failed to fetch model details")
@@ -746,42 +794,3 @@ async def parse(model_id: Text, input_text: Text) -> Dict[Text, Any]:
                 f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
             )
     return json_response
-
-
-async def get_entity_list_for_cli(
-    entity_type: Text, language: Text, pagesize=1, count=None
-):
-    if count is None:
-        print(pagesize)
-        payload = {
-            FILTER: {ENTITY_TYPE: entity_type, LANGUAGE: language},
-            SEARCH: "",
-            PAGE_NUMBER: 1,
-            PAGE_SIZE: pagesize,
-        }
-    else:
-        payload = {
-            FILTER: {ENTITY_TYPE: entity_type, LANGUAGE: language},
-            SEARCH: "",
-            PAGE_NUMBER: 1,
-            PAGE_SIZE: int(count),
-        }
-    HEADERS = copy(COMMON_HEADERS)
-    HEADERS[AUTHORIZATION] = get_auth_token()
-
-    async with get_async_http_session().post(
-        url=f"{neuralspace_url()}/{LIST_ENTITY_URL}",
-        data=json.dumps(payload, ensure_ascii=False),
-        headers=HEADERS,
-    ) as response:
-        json_response = await response.json(encoding="utf-8")
-        if is_success_status(response.status):
-            if count is None:
-                count = json_response[DATA][COUNT]
-                return int(count)
-            else:
-                entities_supported = [
-                    data["entity"] for data in json_response[DATA][ENTITIES]
-                ]
-                return entities_supported
-        return json_response
