@@ -23,6 +23,7 @@ from neuralspace.constants import (
     RED_END,
     RED_START,
 )
+from neuralspace.datamodels import DatasetTypes
 from neuralspace.nlu.apis import (
     create_project,
     delete_examples,
@@ -53,9 +54,9 @@ class MappingClass(click.ParamType):
         param: typing.Optional["Parameter"],
         ctx: typing.Optional["Context"],
     ) -> typing.Any:
-        list_of_entity_mapping = value.split(",")
+        entity_mapping = value.split(",")
         total_entity_mapping = []
-        for entities in list_of_entity_mapping:
+        for entities in entity_mapping:
             total_entity_mapping.append(entities.split(":"))
         entity_mapping = dict()
         for entity in total_entity_mapping:
@@ -90,7 +91,7 @@ def nlu_get_languages(log_level: Text):
 
 @nlu.command(name="convert-dataset")
 @click.option(
-    "-f",
+    "-F",
     "--from-platform",
     type=click.Choice(["dialogflow", "rasa"], case_sensitive=False),
     required=True,
@@ -99,7 +100,7 @@ def nlu_get_languages(log_level: Text):
 @click.option(
     "-at",
     "--auto-tag-entities",
-    type=click.BOOL,
+    is_flag=True,
     default=False,
     help="You can use auto-tag entities to tag the entities with our pre-trained entities",
 )
@@ -122,12 +123,13 @@ def nlu_get_languages(log_level: Text):
     "--data-type",
     type=click.Choice(["train", "test"], case_sensitive=True),
     default="train",
-    help="you can decide whether you want it as test or train data",
+    help="you can decide whether you want it as test or train data. Defaults to train.",
 )
 @click.option(
     "-d",
     "--input-path",
     required=True,
+    multiple=True,
     help="Name of the folder in which the dataset files are in",
 )
 @click.option(
@@ -155,7 +157,9 @@ def converter(
                 auto_tag_entities=auto_tag_entities,
             )
             converter.convert(
-                input_path=input_path, output_path=output_path, type_of_data=data_type
+                input_path=input_path,
+                output_directory=Path(output_path),
+                dataset_type=DatasetTypes(data_type).value,
             )
             console.print(
                 f"> {GREEN_TICK} SUCCESS Your {from_platform} dataset is now converted to Neuralspace-platform data"
@@ -174,7 +178,9 @@ def converter(
                 auto_tag_entities=auto_tag_entities,
             )
             converter.convert(
-                input_path=input_path, output_path=output_path, type_of_data=data_type
+                input_path=input_path,
+                output_directory=Path(output_path),
+                dataset_type=DatasetTypes(data_type).value,
             )
 
     else:
